import os
import sys
from subprocess import call
import shutil


def directory_assertions(filename):
   isdir = os.path.isdir
   assert os.path.isdir(filename), "Not a valid directory"
   # If the NEMO folder argument is outside NEMOGCM, select NEMOGCM as a directory"
   if isdir(filename+"/NEMOGCM"):
      filename = filename+"/NEMOGCM"
   # Various assertions
   assert isdir(filename+"/CONFIG"), "Not a valid NEMO directory: CONFIG folder missing."
   assert isdir(filename+"/ARCH"), "Not a valid NEMO directory: ARCH folder missing."
   assert isdir(filename+"/TOOLS"), "Not a valid NEMO directory: TOOLS folder missing."
   assert isdir(filename+"/TOOLS/MPP_PREP"), "Not a valid NEMO directory: MPP_PREP folder inside TOOLS is missing."
   return filename 

filename = directory_assertions(sys.argv[-1])

# Simple archfile containing netcdf path and compilation flags
archfile = '''
%CPP                      cpp

%NCDF_INC            -I/apps/NETCDF/4.2-parallel/IMPI/include
%NCDF_LIB            -L/apps/NETCDF/4.2-parallel/IMPI/lib -lnetcdf -lnetcdff

%CPP                      cpp
%FC                  mpiifort
%FCFLAGS             -ip -r8 -O3 -fp-model strict -xHost -extend-source 132 -heap-arrays -g -traceback -finstrument-functions
%FFFLAGS             -ip -r8 -O3 -fp-model strict -xHost -extend-source 132 -heap-arrays -g -traceback -finstrument-functions
%LD                  mpiifort
%FPPFLAGS            -P -C -traditional
%LDFLAGS             -lstdc++
%AR                  ar
%ARFLAGS             -r
%MK                  gmake
%USER_INC            %NCDF_INC
%USER_LIB            %NCDF_LIB
'''
toolsfolder = filename+"/TOOLS/"

job = '''
cd %s 
./maketools -n MPP_PREP clean
./maketools -n MPP_PREP -m tools -j 8
''' % toolsfolder 

with open(filename+"/ARCH/arch-tools.fcm","w") as arch:
   arch.write(archfile)
   arch.close()

print "Compiling tool..."
with open("log.err","w") as errf:
   with open("log.out","w") as outf:
         err_status = call(job,stdout=errf,stderr=errf,shell=True)

if err_status:
   with open("log.err","r") as errf:
      with open("log.out","r") as outf:
         #print "StdOUT:"
         #print outf.read()
         print "StdERR:"
         print errf.read()
   print "Something went wrong! ^^^^ LOG ^^^^"
else:
   print "Tool Compiled!"

os.remove(filename+"/ARCH/arch-tools.fcm")
os.remove("log.out")
os.remove("log.err")

# 
# src = filename+"/TOOLS/MPP_PREP/mpp_optimiz_zoom_nc.exe"
# dst = "./mpp_optimiz_zoom_nc.exe"
# shutil.copy(src, dst)

src = filename+"/TOOLS/MPP_PREP/mppopt_showproc_nc.exe"
dst = "bin/find_sea_procs.exe"
shutil.copy(src, dst)
